"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
var fs = __importStar(require("fs"));
var PATH = __importStar(require("path"));
var child_process_1 = require("child_process");
var Run = /** @class */ (function () {
    // ########################################
    function Run(consoleArguments, commandSettings, rulesetValidation) {
        this.consoleArguments = consoleArguments;
        this.commandSettings = commandSettings;
        this.rulesetValidation = rulesetValidation;
        // ########################################
        this.params = {};
        this.statusToOutput = false;
    }
    // ########################################
    Run.prototype.process = function () {
        var _this = this;
        this.init();
        var relativePathToCommand = PATH.resolve(Run.TSC_NODE_COMMAND);
        var relativePathToRuleset = PATH.resolve(this.params[Run.RULSET_FLAG]);
        if (!fs.existsSync(this.params[Run.RULSET_FLAG])) {
            throw new Error('Ruleset file don\'t exist!');
        }
        if (!this.rulesetValidation.isValid(relativePathToRuleset)) {
            var outputError_1 = '';
            this.rulesetValidation.getErrorsMessages().forEach(function (error) {
                outputError_1 += error + '\n';
            });
            throw new Error(outputError_1);
        }
        child_process_1.exec(relativePathToCommand + " -p " + relativePathToRuleset + " || exit 0", function (error, stdout, stderr) {
            if (error) {
                var output_1 = _this.printOutput(error, 'Error');
                process.stderr.write("exec error: " + output_1);
                return;
            }
            if (stdout) {
                var output_2 = _this.printOutput(stdout, 'Error');
                process.stderr.write("" + output_2);
                return;
            }
            if (stderr) {
                var output_3 = _this.printOutput(stderr, 'Error');
                process.stderr.write("" + output_3);
                return;
            }
            var output = _this.printOutput("TypeScript syntax validated successfully!", 'Success');
            process.stdout.write(output);
            return;
        });
    };
    // ########################################
    Run.prototype.init = function () {
        var _this = this;
        this.consoleArguments.forEach(function (arg) {
            if (arg.includes('--status-to-output')) {
                _this.statusToOutput = true;
            }
            if (arg.includes(Run.RULSET_FLAG)) {
                _this.params[Run.RULSET_FLAG] = _this.getArgumentByName(arg);
                return;
            }
        });
    };
    // ########################################
    Run.prototype.printOutput = function (message, status) {
        if (this.statusToOutput) {
            var outputObject = {
                status: status,
                output: message
            };
            return JSON.stringify(outputObject);
        }
        else {
            return message;
        }
    };
    Run.prototype.getArgumentByName = function (paramStr) {
        var splittingParam = paramStr.split('=');
        return splittingParam[1];
    };
    // ########################################
    Run.TSC_NODE_COMMAND = './node_modules/.bin/tsc';
    Run.RULSET_FLAG = '--ruleset';
    return Run;
}());
exports.Run = Run;
